==> spring-cloud-contract-shade-3.1.3-sources.jar: shaded/org/apache/maven/wagon/authorization/AuthorizationException.java <==
package shaded.shaded.org.apache.maven.wagon.authorization;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import shaded.shaded.org.apache.maven.wagon.WagonException;

/**
 * This exception is thrown when the user is not entitled to fetch from or deploy to
 * particular place in the repository.
 *
 * @author <a href="michal.maczka@dimatics.com">Michal Maczka</a>
 *
 */
public class AuthorizationException
    extends WagonException
{


    /**
     * @see shaded.shaded.org.apache.maven.wagon.WagonException
     */
    public AuthorizationException( final String message )
    {
        super( message );
    }

    /**
     * @see shaded.shaded.org.apache.maven.wagon.WagonException
     */
    public AuthorizationException( final String message, final Throwable cause )
    {
        super( message, cause );
    }


}

==> spring-cloud-contract-shade-4.3.0-sources.jar: shaded/org/apache/maven/wagon/authorization/AuthorizationException.java <==
package shaded.org.apache.maven.wagon.authorization;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import shaded.org.apache.maven.wagon.WagonException;

/**
 * This exception is thrown when the user is not entitled to fetch from or deploy to
 * particular place in the repository.
 *
 * @author <a href="michal.maczka@dimatics.com">Michal Maczka</a>
 *
 */
public class AuthorizationException
    extends WagonException
{


    /**
     * @see org.apache.maven.wagon.WagonException
     */
    public AuthorizationException( final String message )
    {
        super( message );
    }

    /**
     * @see org.apache.maven.wagon.WagonException
     */
    public AuthorizationException( final String message, final Throwable cause )
    {
        super( message, cause );
    }


}
